GatewayEvent class

Constructors

GatewayEvent()

Properties

documentId ↔ String?
getter/setter pair
entity ↔ String?
getter/setter pair
event ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
identifier ↔ String?
getter/setter pair
payload ↔ Payload?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
txnId ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited