MethodChannelKycWorkflow class

An implementation of KycWorkflowPlatform that uses method channels.

Inheritance

Constructors

MethodChannelKycWorkflow()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start(String documentId, String identifier, String tokenId, HashMap<String, String>? additionalData, DigioConfig digioConfig, GatewayEventListenerImpl callback) → Future<Map<Object?, Object?>?>
override
startStateless(StatelessConfig config, StatelessEventListenerImpl eventListener) → Future<Map<Object?, Object?>?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited