KycWorkflowPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • KycWorkflowPlatform
Implementers

Constructors

KycWorkflowPlatform()
Constructs a KycWorkflowPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start(String documentId, String identifier, String tokenId, HashMap<String, String>? additionalData, DigioConfig digioConfig, GatewayEventListenerImpl gatewayEventListener) → Future<Map<Object?, Object?>?>
startStateless(StatelessConfig config, StatelessEventListenerImpl eventListener) → Future<Map<Object?, Object?>?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ KycWorkflowPlatform
The default instance of KycWorkflowPlatform to use.
getter/setter pair