SelfieConfig class

Constructors

SelfieConfig({bool autoCapture = false, bool showInstruction = true, bool previewSkip = false, bool hasGeotagging = false, bool enableLiveness = false, String? logoUrl})

Properties

autoCapture bool
getter/setter pair
enableLiveness bool
getter/setter pair
hasGeotagging bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
logoUrl String?
getter/setter pair
previewSkip bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showInstruction bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited