StatelessEvent class

Constructors

StatelessEvent({String? screen, String? action, Map<Object?, Object?>? raw})

Properties

action String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
raw Map<Object?, Object?>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screen String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromMap(Map<Object?, Object?>? map) StatelessEvent