StatelessUpiConfig class
Constructors
- StatelessUpiConfig({required UpiServiceMode serviceMode, required String requestId, required PspMode pspMode, String? pspPackage, String? upiIntentUri, String? logoUrl, int? loaderColor})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- loaderColor ↔ int?
-
getter/setter pair
- logoUrl ↔ String?
-
getter/setter pair
- pspMode ↔ PspMode
-
getter/setter pair
- pspPackage ↔ String?
-
getter/setter pair
- requestId ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceMode ↔ UpiServiceMode
-
getter/setter pair
- upiIntentUri ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited