StatelessResponse class
Constructors
-
StatelessResponse({FlowStatus status = FlowStatus.FAILED, List<
SdkTaskResponse> results = const [], String? error})
Properties
- error ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
results
↔ List<
SdkTaskResponse> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ FlowStatus
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromMap(
Map< Object?, Object?> ? map) → StatelessResponse